
-- from sam_lie
-- Compatible with Lua 5.0 and 5.1.
-- Disclaimer : use at own risk especially for hedge fund reports :-)

---============================================================
-- add comma to separate thousands
-- 
function comma_value(amount)
  local formatted = amount
  while true do  
    formatted, k = string.gsub(formatted, "^(-?%d+)(%d%d%d)", '%1 %2')
    if (k==0) then
      break
    end
  end
  return formatted
end

---============================================================
-- rounds a number to the nearest decimal places
--
function round(val, decimal)
  if (decimal) then
    return math.floor( (val * 10^decimal) + 0.5) / (10^decimal)
  else
    return math.floor(val+0.5)
  end
end

--===================================================================
-- given a numeric value formats output with comma to separate thousands
-- and rounded to given decimal places
--
--
function format_num(amount, decimal, prefix, neg_prefix)
  local str_amount,  formatted, famount, remain

  decimal = decimal or 2  -- default 2 decimal places
  neg_prefix = neg_prefix or "-" -- default negative sign

  famount = math.abs(round(amount,decimal))
  famount = math.floor(famount)

  remain = round(math.abs(amount) - famount, decimal)

        -- comma to separate the thousands
  formatted = comma_value(famount)

        -- attach the decimal portion
  if (decimal > 0) then
    remain = string.sub(tostring(remain),3)
    formatted = formatted .. "." .. remain ..
                string.rep("0", decimal - string.len(remain))
  end

        -- attach prefix string e.g '$' 
  formatted = (prefix or "") .. formatted 

        -- if value is negative then format accordingly
  if (amount<0) then
    if (neg_prefix=="()") then
      formatted = "("..formatted ..")"
    else
      formatted = neg_prefix .. formatted 
    end
  end

  return formatted
end

-- Example usage:
-- 
-- amount = 1333444.1
-- print(format_num(amount,2))
-- print(format_num(amount,-2,"US$"))
-- 
-- amount = -22333444.5634
-- print(format_num(amount,2,"$"))
-- print(format_num(amount,2,"$","()"))
-- print(format_num(amount,3,"$","NEG "))
-- Output:
-- 
-- 1,333,444.10
-- US$1,333,400
-- -$22,333,444.56
-- ($22,333,444.56)
-- NEG $22,333,444.563








-- MES FONCTIONS

function trim(s)
   return (s:gsub("^%s*(.-)%s*$", "%1"))
end

function FirstLetterUpper(str)
    return (str:gsub("^%l", string.upper))
end

function round(num, idp)

  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
  
end 

function RetournerDureeDepuisTimestamp (timestamp)

	local tmp  = os.time() - timestamp
	
	if (tmp/60>=1) then
		tmp=tmp/60
		if (tmp/60>=1) then
			tmp=tmp/60
			if (tmp/24>=1) then
				tmp=tmp/24
				return  round(tmp,0).."#MiniDay#"
			else
				return  round(tmp,0).."h"
			end
		else
			return  round(tmp,0).."min"
		end
	else
		return  round(tmp,0).."s"
	end
end

function RetournerDureeDepuisTimestampSecondes (timestamp)

	return (os.time() - timestamp)
	
end

function NettoyerTitreFilm (chaine)
		
	chaine = string.gsub(chaine, "\ ", "\.")
	chaine = string.gsub(chaine, "%_", "%.")

	chaine = string.gsub(chaine, "[\-\.]HDMA", "")
	

	chaine = string.gsub(chaine, "[uU]ltimate%-[tT]orrent%.ws", "")
	chaine = string.gsub(chaine, "[wW][wW][wW]\.", "")
	chaine = string.gsub(chaine, "Cpas[bB]ien\.(%a%a%a)", "")
	chaine = string.gsub(chaine, "Cpas[bB]ien\.(%a%a)", "")
	chaine = string.gsub(chaine, "[tT]orrent9\.(%a%a%a%a)", "")
	chaine = string.gsub(chaine, "[tT]orrent9\.(%a%a%a)", "")
	chaine = string.gsub(chaine, "[tT]orrent9\.(%a%a)", "")
	chaine = string.gsub(chaine, "T9\.(%a%a)", "")
				
	chaine = string.gsub(chaine, "yggtorrent\.(%a%a%a)", "")

	chaine = string.gsub(chaine, "%.avi", "")
	chaine = string.gsub(chaine, "%.mkv", "")
	chaine = string.gsub(chaine, "%.mp4", "")
	chaine = string.gsub(chaine, "%.mpg", "")
	
	chaine = string.gsub(chaine, "WEBR[iI][pP]", "")
	chaine = string.gsub(chaine, "[hH][dD][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[xX][vV][iI][dD]", "")
	chaine = string.gsub(chaine, "[bB][dD][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[bB][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[dD][vV][dD][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[wW][eE][bB][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[wW][eE][bB]-[dD][lL]", "")
	chaine = string.gsub(chaine, "[hH][dD][lL][iI][gG][hH][tT]", "")
	chaine = string.gsub(chaine, "[\. ][mM][uU][lL][tT][iI][\. ]", "\.")

	chaine = string.gsub(chaine, "-Xantar", "")
	chaine = string.gsub(chaine, "-Tw0l3ros", "")
	chaine = string.gsub(chaine, "-STVFRV", "")
	chaine = string.gsub(chaine, "STVFRV", "")
	chaine = string.gsub(chaine, "-STV", "")
	chaine = string.gsub(chaine, "\.STV", "")

	chaine = string.gsub(chaine, "\.5\.1", "")
	chaine = string.gsub(chaine, "-[nN][oO][tT][aA][gG]", "")
	chaine = string.gsub(chaine, "[nN][oO][tT][aA][gG]", "")
	chaine = string.gsub(chaine, "-XSHD", "")
	chaine = string.gsub(chaine, "-GOLDORAK", "")
	chaine = string.gsub(chaine, "-Speedfire93", "")
	chaine = string.gsub(chaine, "-Visual", "")
	chaine = string.gsub(chaine, "-ulshd", "")
	chaine = string.gsub(chaine, "-AKLHD", "")
	chaine = string.gsub(chaine, "-ZorroHD", "")
	chaine = string.gsub(chaine, "-ENG", "")
	chaine = string.gsub(chaine, "-L[iI]BERTAD", "")
	chaine = string.gsub(chaine, "[%. ]AAC", "")
	chaine = string.gsub(chaine, "Zone80", "")
	chaine = string.gsub(chaine, "WEB%-DL", "")
	chaine = string.gsub(chaine, "VFF[%.-]EN", "")
	chaine = string.gsub(chaine, "VFF", "")
	chaine = string.gsub(chaine, "-mHDgz", "")
	chaine = string.gsub(chaine, "mHDgz", "")
	chaine = string.gsub(chaine, "mHD", "")
	chaine = string.gsub(chaine, "-R3N", "")
	chaine = string.gsub(chaine, "Hon3y", "")
	chaine = string.gsub(chaine, "LIMITED", "")
	chaine = string.gsub(chaine, "DDP5\.1\.", "\.")
	chaine = string.gsub(chaine, "DD5\.1\.", "\.")
	chaine = string.gsub(chaine, "5\.1\.", "\.")
	chaine = string.gsub(chaine, "\.PAL", "")
	chaine = string.gsub(chaine, "\.[aA][cC]3", "")
	chaine = string.gsub(chaine, "\.DVD5", "")
	chaine = string.gsub(chaine, "\.[tT][rR][uU][eE][fF][rR][eE][nN][cC][hH]\.", "\.")
	-- chaine = string.gsub(chaine, "\.[fF][rR][eE][nN][cC][hH]\.", "\.")
	chaine = string.gsub(chaine, "\.MD\.", "\.")
	chaine = string.gsub(chaine, "\.HC\.", "\.")
	chaine = string.gsub(chaine, "\.UHD\.", "\.")


	chaine = string.gsub(chaine, ".aaac", "")
	chaine = string.gsub(chaine, ".avc", "")
	chaine = string.gsub(chaine, "REMUX", "")
	chaine = string.gsub(chaine, "MPEG2", "")
	chaine = string.gsub(chaine, "VF2", "")
	chaine = string.gsub(chaine, "MA.[xX]26[4-5]", "")
	chaine = string.gsub(chaine, "Light.[xX]26[4-5]", "")
	chaine = string.gsub(chaine, "[xX]26[4-5]", "")
	chaine = string.gsub(chaine, "-AMNESIA", "")
	chaine = string.gsub(chaine, "-itamma", "")
	chaine = string.gsub(chaine, ".10bits", "")
	chaine = string.gsub(chaine, ".10bit", "")
	chaine = string.gsub(chaine, ".AMZN", "")
	chaine = string.gsub(chaine, ".GHT", "")
	chaine = string.gsub(chaine, ".FRENCH", ".")
	chaine = string.gsub(chaine, "-NSP", "")
	chaine = string.gsub(chaine, "-Candia", "")
	chaine = string.gsub(chaine, "-PSA", "")
	chaine = string.gsub(chaine, "-ETRG", "")
	chaine = string.gsub(chaine, "AUTOPSiE", "")
	chaine = string.gsub(chaine, "[bB][rR][rR][iI][pP]", "")
	chaine = string.gsub(chaine, "[bB][lL][uU]\-[rR][aA][yY]", "")
	chaine = string.gsub(chaine, "[bB][lL][uU][rR][aA][yY]", "")
	chaine = string.gsub(chaine, "DTS%-HD", "")
	chaine = string.gsub(chaine, "DTS", "")
	chaine = string.gsub(chaine, "-EXTREME", "")
	chaine = string.gsub(chaine, "-ACOOL", "")
	chaine = string.gsub(chaine, "-Jethro", "")
	chaine = string.gsub(chaine, "-BRiNK", "")
	chaine = string.gsub(chaine, "-NLX5", "")
	chaine = string.gsub(chaine, "KiNGDOM", "")
	chaine = string.gsub(chaine, "-Goatlove", "")
	chaine = string.gsub(chaine, "-PREUMS", "")
	chaine = string.gsub(chaine, "-URAM", "")
	chaine = string.gsub(chaine, "-Ulysse", "")
	chaine = string.gsub(chaine, "-PHI", "")
	chaine = string.gsub(chaine, "FR EN", "")
	chaine = string.gsub(chaine, "-gismo65", "")
	chaine = string.gsub(chaine, "-DesTroY", "")
	chaine = string.gsub(chaine, "-ZEST", "")
	chaine = string.gsub(chaine, "-NEO", "")
	chaine = string.gsub(chaine, "-SHARKS", "")
	chaine = string.gsub(chaine, "-CNF30", "")
	chaine = string.gsub(chaine, "-Winks", "")
	chaine = string.gsub(chaine, "-Loys", "")
	chaine = string.gsub(chaine, "-DOUCHEBAGS", "")
	chaine = string.gsub(chaine, "-STARLER", "")
	chaine = string.gsub(chaine, "-ROUGH", "")
	chaine = string.gsub(chaine, "L[iI]M[iI]TED", "")
	chaine = string.gsub(chaine, "-AiRLiNE", "")
	chaine = string.gsub(chaine, "-PiNKPANTERS", "")
	chaine = string.gsub(chaine, "HDMANEO", "")
	chaine = string.gsub(chaine, "HEVC", "")
	chaine = string.gsub(chaine, "-BACKUP", "")
	chaine = string.gsub(chaine, "-XCON", "")
	chaine = string.gsub(chaine, "_Elly", "")
	chaine = string.gsub(chaine, "X624", "")
	chaine = string.gsub(chaine, "[hH]264", "")
	chaine = string.gsub(chaine, "[hH].264", "")
	chaine = string.gsub(chaine, "HooPa", "")
	chaine = string.gsub(chaine, "-[lL][oO][sS][tT]", "")
	chaine = string.gsub(chaine, "%[ATG", "%[")
	chaine = string.gsub(chaine, "-GAZOAL", "")
	chaine = string.gsub(chaine, "-GAZOAL", "")
	chaine = string.gsub(chaine, "-Ozlem", "")
	chaine = string.gsub(chaine, "-HARDLiNE", "")
	chaine = string.gsub(chaine, "-DTOne", "")
	chaine = string.gsub(chaine, "-LAZARUS", "")
	chaine = string.gsub(chaine, "-GHZ", "")
	chaine = string.gsub(chaine, "-DuSS", "")
	chaine = string.gsub(chaine, "DD5[%. ]1", "")
	chaine = string.gsub(chaine, "RERiP", "")
	chaine = string.gsub(chaine, "-Tyson", "")
	chaine = string.gsub(chaine, "UNRATED", "")
	chaine = string.gsub(chaine, "-NoTag", "")
	chaine = string.gsub(chaine, "-worldmkv", "")
	chaine = string.gsub(chaine, "-PopHD", "")
	chaine = string.gsub(chaine, "-Pop", "")
	chaine = string.gsub(chaine, "-STARLIGHTER", "")
	chaine = string.gsub(chaine, "-ULS", "")
	chaine = string.gsub(chaine, "-UTT", "")
	chaine = string.gsub(chaine, "-DON", "")
	chaine = string.gsub(chaine, "-FiDO", "")
	chaine = string.gsub(chaine, "-Slay3R", "")
	chaine = string.gsub(chaine, "Up4U", "")
	chaine = string.gsub(chaine, "iNTERNAL", "")
	chaine = string.gsub(chaine, "-VENUE", "")
	chaine = string.gsub(chaine, "-CARPEDIEM", "")
	chaine = string.gsub(chaine, "-TOXIC", "")
	chaine = string.gsub(chaine, "-FrIeNdS", "")
	chaine = string.gsub(chaine, "%.NF%.", "")
	chaine = string.gsub(chaine, "FR%.EN", "")
	chaine = string.gsub(chaine, "-SiGeRiS", "")
	chaine = string.gsub(chaine, "-ARK01", "")
	chaine = string.gsub(chaine, "-CiELOS", "")
	chaine = string.gsub(chaine, "-RDH", "")
	chaine = string.gsub(chaine, "-FHD", "")
	chaine = string.gsub(chaine, "-LRDP", "")
	chaine = string.gsub(chaine, "EXTENDED", "")
	chaine = string.gsub(chaine, "\.WEB\.", "")
	chaine = string.gsub(chaine, "\.DUAL\.", "")
	chaine = string.gsub(chaine, "\.VF\.", "")
	chaine = string.gsub(chaine, "\.Remux\.", "")
	chaine = string.gsub(chaine, "(Aja,", "")
	chaine = string.gsub(chaine, ".AVC", "")
	chaine = string.gsub(chaine, ".VO", "")
	chaine = string.gsub(chaine, "STFR", "")

	chaine = string.gsub(chaine, "L%.", "L\'")
	
	-- FINAL

	chaine = string.gsub(chaine, "[()]", "")
	chaine = string.gsub(chaine, "%.%.", "%.")
	chaine = string.gsub(chaine, "%.%.", "%.")
	chaine = string.gsub(chaine, "%[ %] ", "")
	chaine = string.gsub(chaine, "%[%] ", "")
	chaine = string.gsub(chaine, "%[", "")
	chaine = string.gsub(chaine, "%]", "")
	chaine = string.gsub(chaine, "%.", " ")
	chaine = string.gsub(chaine, "- ", "")
	chaine = string.gsub(chaine, " -", "")

	chaine = string.gsub(chaine, "  ", " ")
	chaine = string.gsub(chaine, "  ", " ")

	chaine = string.gsub(chaine, "HDR", "(HDR)")
	chaine = string.gsub(chaine, "720[pP]", "(720p)")
	chaine = string.gsub(chaine, "1080[pP]", "(1080p)")
	chaine = string.gsub(chaine, "2160[pP]", "(2160p)")

	chaine = string.gsub(chaine, "1940", "(1940)")
	chaine = string.gsub(chaine, "1941", "(1941)")
	chaine = string.gsub(chaine, "1942", "(1942)")
	chaine = string.gsub(chaine, "1943", "(1943)")
	chaine = string.gsub(chaine, "1944", "(1944)")
	chaine = string.gsub(chaine, "1945", "(1945)")
	chaine = string.gsub(chaine, "1946", "(1946)")
	chaine = string.gsub(chaine, "1947", "(1947)")
	chaine = string.gsub(chaine, "1948", "(1948)")
	chaine = string.gsub(chaine, "1949", "(1949)")

	chaine = string.gsub(chaine, "1950", "(1950)")
	chaine = string.gsub(chaine, "1951", "(1951)")
	chaine = string.gsub(chaine, "1952", "(1952)")
	chaine = string.gsub(chaine, "1953", "(1953)")
	chaine = string.gsub(chaine, "1954", "(1954)")
	chaine = string.gsub(chaine, "1955", "(1955)")
	chaine = string.gsub(chaine, "1956", "(1956)")
	chaine = string.gsub(chaine, "1957", "(1957)")
	chaine = string.gsub(chaine, "1958", "(1958)")
	chaine = string.gsub(chaine, "1959", "(1959)")

	chaine = string.gsub(chaine, "1960", "(1960)")
	chaine = string.gsub(chaine, "1961", "(1961)")
	chaine = string.gsub(chaine, "1962", "(1962)")
	chaine = string.gsub(chaine, "1963", "(1963)")
	chaine = string.gsub(chaine, "1964", "(1964)")
	chaine = string.gsub(chaine, "1965", "(1965)")
	chaine = string.gsub(chaine, "1966", "(1966)")
	chaine = string.gsub(chaine, "1967", "(1967)")
	chaine = string.gsub(chaine, "1968", "(1968)")
	chaine = string.gsub(chaine, "1969", "(1969)")

	chaine = string.gsub(chaine, "1970", "(1970)")
	chaine = string.gsub(chaine, "1971", "(1971)")
	chaine = string.gsub(chaine, "1972", "(1972)")
	chaine = string.gsub(chaine, "1973", "(1973)")
	chaine = string.gsub(chaine, "1974", "(1974)")
	chaine = string.gsub(chaine, "1975", "(1975)")
	chaine = string.gsub(chaine, "1976", "(1976)")
	chaine = string.gsub(chaine, "1977", "(1977)")
	chaine = string.gsub(chaine, "1978", "(1978)")
	chaine = string.gsub(chaine, "1979", "(1979)")

	chaine = string.gsub(chaine, "1980", "(1980)")
	chaine = string.gsub(chaine, "1981", "(1981)")
	chaine = string.gsub(chaine, "1982", "(1982)")
	chaine = string.gsub(chaine, "1983", "(1983)")
	chaine = string.gsub(chaine, "1984", "(1984)")
	chaine = string.gsub(chaine, "1985", "(1985)")
	chaine = string.gsub(chaine, "1986", "(1986)")
	chaine = string.gsub(chaine, "1987", "(1987)")
	chaine = string.gsub(chaine, "1988", "(1988)")
	chaine = string.gsub(chaine, "1989", "(1989)")

	chaine = string.gsub(chaine, "1990", "(1990)")
	chaine = string.gsub(chaine, "1991", "(1991)")
	chaine = string.gsub(chaine, "1992", "(1992)")
	chaine = string.gsub(chaine, "1993", "(1993)")
	chaine = string.gsub(chaine, "1994", "(1994)")
	chaine = string.gsub(chaine, "1995", "(1995)")
	chaine = string.gsub(chaine, "1996", "(1996)")
	chaine = string.gsub(chaine, "1997", "(1997)")
	chaine = string.gsub(chaine, "1998", "(1998)")
	chaine = string.gsub(chaine, "1999", "(1999)")

	chaine = string.gsub(chaine, "2000", "(2000)")
	chaine = string.gsub(chaine, "2001", "(2001)")
	chaine = string.gsub(chaine, "2002", "(2002)")
	chaine = string.gsub(chaine, "2003", "(2003)")
	chaine = string.gsub(chaine, "2004", "(2004)")
	chaine = string.gsub(chaine, "2005", "(2005)")
	chaine = string.gsub(chaine, "2006", "(2006)")
	chaine = string.gsub(chaine, "2007", "(2007)")
	chaine = string.gsub(chaine, "2008", "(2008)")
	chaine = string.gsub(chaine, "2009", "(2009)")

	chaine = string.gsub(chaine, "2010", "(2010)")
	chaine = string.gsub(chaine, "2011", "(2011)")
	chaine = string.gsub(chaine, "2012", "(2012)")
	chaine = string.gsub(chaine, "2013", "(2013)")
	chaine = string.gsub(chaine, "2014", "(2014)")
	chaine = string.gsub(chaine, "2015", "(2015)")
	chaine = string.gsub(chaine, "2016", "(2016)")
	chaine = string.gsub(chaine, "2017", "(2017)")
	chaine = string.gsub(chaine, "2018", "(2018)")
	chaine = string.gsub(chaine, "2019", "(2019)")

	chaine = trim(FirstLetterUpper(chaine))	
	return chaine

end













